{ lib, pkgs, config,  ... }:
let
  secrets = config.myEnv.websites.isabelle.aten_integration;
  webRoot = "/var/lib/ftp/immae/aten/public";
  cfg = config.myServices.websites.isabelle.aten_integration;
  pcfg = config.services.phpApplication;
in {
  options.myServices.websites.isabelle.aten_integration.enable = lib.mkEnableOption "enable Aten's website in integration";

  config = lib.mkIf cfg.enable {
    services.phpApplication.apps.isabelle_aten_integration = {
      websiteEnv = "integration";
      httpdUser = config.services.httpd.Inte.user;
      httpdGroup = config.services.httpd.Inte.group;
      httpdWatchFiles = [
        config.secrets.fullPaths."websites/isabelle/aten_integration"
      ];
      inherit webRoot;
      varDir = "/var/lib/ftp/immae/aten_var";
      app = "/var/lib/ftp/immae/aten";
      serviceDeps = [ "postgresql.service" ];
      preStartActions = [
        "APP_ENV=dev ./bin/console --env=dev cache:clear --no-warmup"
      ];
      phpOpenbasedir = [ "/tmp" ];
      phpPool = {
        "php_admin_value[upload_max_filesize]" = "20M";
        "php_admin_value[post_max_size]" = "20M";
        #"php_admin_flag[log_errors]" = "on";
        "pm" = "ondemand";
        "pm.max_children" = "5";
        "pm.process_idle_timeout" = "60";
      };
      phpEnv = {
        SYMFONY_DEBUG_MODE = "\"yes\"";
      };
      phpPackage = pkgs.php72;
    };

    secrets.keys."websites/isabelle/aten_integration" = {
      user = config.services.httpd.Inte.user;
      group = config.services.httpd.Inte.group;
      permissions = "0400";
      text = let
        # cf:
        #   https://secure.php.net/manual/fr/function.parse-url.php
        #   vendor/doctrine/dbal/lib/Doctrine/DBAL/DriverManager.php#parseDatabaseUrlQuery
        psql_url = with secrets.postgresql; "pdo-pgsql://${user}:${password}@invalid:${port}/${database}?host=${socket}";
      in ''
        SetEnv APP_ENV      "dev"
        SetEnv APP_SECRET   "${secrets.secret}"
        SetEnv DATABASE_URL "${psql_url}"
        '';
    };
    services.websites.env.integration.vhostConfs.isabelle_aten_integration = {
      certName    = "integration";
      addToCerts  = true;
      hosts       = [ "dev.aten.pro" ];
      root        = webRoot;
      extraConfig = [
        ''
        <FilesMatch "\.php$">
          SetHandler "proxy:unix:${pcfg.phpListenPaths.isabelle_aten_integration}|fcgi://localhost"
        </FilesMatch>

        Include ${config.secrets.fullPaths."websites/isabelle/aten_integration"}

        <Location />
          Use LDAPConnect
          Require ldap-group   cn=dev.aten.pro,cn=httpd,ou=services,dc=immae,dc=eu
          ErrorDocument 401 "<html><meta http-equiv=\"refresh\" content=\"0;url=https://aten.pro\"></html>"
        </Location>

        <Location /backend>
          Use LDAPConnect
          Require ldap-group   cn=dev.aten.pro,cn=httpd,ou=services,dc=immae,dc=eu
          ErrorDocument 401 "<html><meta http-equiv=\"refresh\" content=\"0;url=https://aten.pro\"></html>"
        </Location>

        <Directory ${webRoot}>
          Options Indexes FollowSymLinks MultiViews Includes
          AllowOverride All
          Require all granted
          DirectoryIndex index.php
          FallbackResource /index.php
        </Directory>
        ''
      ];
    };
  };
}
